aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/nvim/option.c7
-rw-r--r--src/nvim/version.c2
2 files changed, 5 insertions, 4 deletions
diff --git a/src/nvim/version.c b/src/nvim/version.c
index 06482bf490..f6a9418dbf 100644
--- a/src/nvim/version.c
+++ b/src/nvim/version.c
@@ -846,7 +846,7 @@ static const int included_patches[] = {
// 109 NA
// 108 NA
// 107 NA
- // 106,
+ 106,
// 105 NA
104,
// 103 NA
diff --git a/src/nvim/option.c b/src/nvim/option.c
index 6ed4989a4c..e989f700ae 100644
--- a/src/nvim/option.c
+++ b/src/nvim/option.c
@@ -2455,13 +2455,14 @@ did_set_string_option (
if ((secure || sandbox != 0)
&& (options[opt_idx].flags & P_SECURE)) {
errmsg = e_secure;
- } else if ((((options[opt_idx].flags & P_NFNAME)
- && vim_strpbrk(*varp, (char_u *)"/\\*?[|;&<>\r\n") != NULL))
+ } else if (((options[opt_idx].flags & P_NFNAME)
+ && vim_strpbrk(*varp, (char_u *)(secure
+ ? "/\\*?[|;&<>\r\n" : "/\\*?[<>\r\n")) != NULL)
|| ((options[opt_idx].flags & P_NDNAME)
&& vim_strpbrk(*varp, (char_u *)"*?[|;&<>\r\n") != NULL)) {
// Check for a "normal" directory or file name in some options. Disallow a
// path separator (slash and/or backslash), wildcards and characters that
// are often illegal in a file name.
errmsg = e_invarg;
}
/* 'backupcopy' */
@@ -2455,13 +2455,14 @@ did_set_string_option (
// Check for a "normal" directory or file name in some options. Disallow a
// path separator (slash and/or backslash), wildcards and characters that
- // are often illegal in a file name.
+ // are often illegal in a file name. Be more permissive if "secure" is off.
errmsg = e_invarg;
}